@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2010 Peng Wu <alexepico@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -36,8 +35,6 @@
 
 #endif
 
-#define IBUS_ENGINE_PLUGIN_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), IBUS_TYPE_ENGINE_PLUGIN, IBusEnginePluginPrivate))
-
 struct _IBusEnginePluginPrivate{
   lua_State * L;
   GArray * lua_commands; /* Array of lua_command_t. */
@@ -46,7 +43,9 @@ struct _IBusEnginePluginPrivate{
   gchar * use_converter;
 };
 
-G_DEFINE_TYPE (IBusEnginePlugin, ibus_engine_plugin, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_CODE (IBusEnginePlugin, ibus_engine_plugin, G_TYPE_OBJECT, G_ADD_PRIVATE (IBusEnginePlugin));
+
+#define IBUS_ENGINE_PLUGIN_GET_PRIVATE(obj) (ibus_engine_plugin_get_instance_private (obj))
 
 static void lua_command_clone(lua_command_t * command, lua_command_t * new_command){
   new_command->command_name = g_strdup(command->command_name);
@@ -171,8 +170,6 @@ ibus_engine_plugin_class_init (IBusEnginePluginClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->finalize = ibus_engine_plugin_finalize;
-
-  g_type_class_add_private (klass, sizeof (IBusEnginePluginPrivate));
 }
 
 static void
@@ -434,7 +431,7 @@ gchar * ibus_engine_plugin_get_first_result(IBusEnginePlugin * plugin){
     lua_pop(L, 2);
   }
 
-  return (const char *)result;
+  return (char *)result;
 }
 
 /**
