@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "PYConfig.h"
 
@@ -42,6 +41,7 @@ Config::initDefaultValues (void)
 {
     m_orientation = IBUS_ORIENTATION_HORIZONTAL;
     m_page_size = 5;
+    m_display_style = DISPLAY_STYLE_TRADITIONAL;
     m_remember_every_input = FALSE;
     m_sort_option = SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY;
     m_show_suggestion = FALSE;
@@ -69,6 +69,14 @@ Config::initDefaultValues (void)
     m_punct_switch = "<Control>period";
     m_both_switch = "";
     m_trad_switch = "<Control><Shift>f";
+
+    m_network_dictionary_start_timestamp = 0;
+    m_network_dictionary_end_timestamp = 0;
+
+    m_enable_cloud_input = FALSE;
+    m_cloud_candidates_number = 1;
+    m_cloud_input_source = CLOUD_INPUT_SOURCE_BAIDU;
+    m_cloud_request_delay_time = 600;
 }
 
 
@@ -119,6 +127,44 @@ Config::read (const gchar * name,
     return defval;
 }
 
+gint64
+Config::read (const gchar * name,
+              gint64        defval)
+{
+    GVariant *value = NULL;
+    if ((value = g_settings_get_value (m_settings, name)) != NULL) {
+        if (g_variant_classify (value) == G_VARIANT_CLASS_INT64)
+            return g_variant_get_int64 (value);
+    }
+
+    g_warn_if_reached ();
+    return defval;
+}
+
+gboolean
+Config::write (const gchar * name, bool val)
+{
+    return g_settings_set_boolean (m_settings, name, val);
+}
+
+gboolean
+Config::write (const gchar * name, gint val)
+{
+    return g_settings_set_int (m_settings, name, val);
+}
+
+gboolean
+Config::write (const gchar * name, const gchar * val)
+{
+    return g_settings_set_string (m_settings, name, val);
+}
+
+gboolean
+Config::write (const gchar * name, gint64 val)
+{
+    return g_settings_set_int64 (m_settings, name, val);
+}
+
 gboolean
 Config::valueChanged (const std::string &schema_id,
                       const std::string &name,
