@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <cstring>
@@ -357,6 +356,7 @@ ExtEditor::processSpace (guint keyval)
     case LABEL_LIST_COMMANDS:
     case LABEL_LIST_DIGIT:
     case LABEL_LIST_ALPHA:
+    case LABEL_LIST_NONE:
         selectCandidate (cursor_pos);
         break;
     case LABEL_LIST_SINGLE:
@@ -529,6 +529,7 @@ ExtEditor::selectCandidate (guint index)
         break;
     case LABEL_LIST_DIGIT:
     case LABEL_LIST_ALPHA:
+    case LABEL_LIST_NONE:
         {
             g_return_val_if_fail (m_result_num > 1, FALSE);
             g_return_val_if_fail (static_cast<int>(index) < m_result_num, FALSE);
