@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "PYPConfig.h"
 
@@ -33,6 +32,7 @@ const gchar * const CONFIG_CORRECT_PINYIN            = "correct-pinyin";
 const gchar * const CONFIG_FUZZY_PINYIN              = "fuzzy-pinyin";
 const gchar * const CONFIG_ORIENTATION               = "lookup-table-orientation";
 const gchar * const CONFIG_PAGE_SIZE                 = "lookup-table-page-size";
+const gchar * const CONFIG_DISPLAY_STYLE             = "display-style";
 const gchar * const CONFIG_REMEMBER_EVERY_INPUT      = "remember-every-input";
 const gchar * const CONFIG_SORT_OPTION               = "sort-candidate-option";
 const gchar * const CONFIG_SHOW_SUGGESTION           = "show-suggestion";
@@ -65,6 +65,12 @@ const gchar * const CONFIG_LETTER_SWITCH             = "letter-switch";
 const gchar * const CONFIG_PUNCT_SWITCH              = "punct-switch";
 const gchar * const CONFIG_BOTH_SWITCH               = "both-switch";
 const gchar * const CONFIG_TRAD_SWITCH               = "trad-switch";
+const gchar * const CONFIG_NETWORK_DICTIONARY_START_TIMESTAMP = "network-dictionary-start-timestamp";
+const gchar * const CONFIG_NETWORK_DICTIONARY_END_TIMESTAMP   = "network-dictionary-end-timestamp";
+const gchar * const CONFIG_INIT_ENABLE_CLOUD_INPUT   = "enable-cloud-input";
+const gchar * const CONFIG_CLOUD_INPUT_SOURCE        = "cloud-input-source";
+const gchar * const CONFIG_CLOUD_CANDIDATES_NUMBER   = "cloud-candidates-number";
+const gchar * const CONFIG_CLOUD_REQUEST_DELAY_TIME  = "cloud-request-delay-time";
 
 const pinyin_option_t PINYIN_DEFAULT_OPTION =
         PINYIN_INCOMPLETE |
@@ -92,6 +98,20 @@ LibPinyinConfig::~LibPinyinConfig (void)
     m_settings = NULL;
 }
 
+gboolean
+LibPinyinConfig::networkDictionaryStartTimestamp (gint64 timestamp)
+{
+    m_network_dictionary_start_timestamp = timestamp;
+    return write (CONFIG_NETWORK_DICTIONARY_START_TIMESTAMP, timestamp);
+}
+
+gboolean
+LibPinyinConfig::networkDictionaryEndTimestamp (gint64 timestamp)
+{
+    m_network_dictionary_end_timestamp = timestamp;
+    return write (CONFIG_NETWORK_DICTIONARY_END_TIMESTAMP, timestamp);
+}
+
 void
 LibPinyinConfig::initDefaultValues (void)
 {
@@ -100,6 +120,7 @@ LibPinyinConfig::initDefaultValues (void)
 
     m_orientation = IBUS_ORIENTATION_HORIZONTAL;
     m_page_size = 5;
+    m_display_style = DISPLAY_STYLE_TRADITIONAL;
     m_remember_every_input = FALSE;
     m_sort_option = SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY;
     m_show_suggestion = FALSE;
@@ -129,6 +150,14 @@ LibPinyinConfig::initDefaultValues (void)
     m_punct_switch = "<Control>period";
     m_both_switch = "";
     m_trad_switch = "<Control><Shift>f";
+
+    m_network_dictionary_start_timestamp = 0;
+    m_network_dictionary_end_timestamp = 0;
+
+    m_enable_cloud_input = FALSE;
+    m_cloud_candidates_number = 1;
+    m_cloud_input_source = CLOUD_INPUT_SOURCE_BAIDU;
+    m_cloud_request_delay_time = 600;
 }
 
 static const struct {
@@ -159,6 +188,23 @@ static const struct{
     {1, SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY}
 };
 
+static const struct{
+    gint display_style_index;
+    DisplayStyle display_style;
+} display_style_options [] = {
+    {0, DISPLAY_STYLE_TRADITIONAL},
+    {1, DISPLAY_STYLE_COMPACT}
+};
+
+static const struct{
+    gint cloud_input_source_index;
+    CloudInputSource cloud_input_source;
+} cloud_input_source_options [] = {
+    {0, CLOUD_INPUT_SOURCE_BAIDU},
+    {1, CLOUD_INPUT_SOURCE_GOOGLE},
+    {2, CLOUD_INPUT_SOURCE_GOOGLE_CN}
+};
+
 void
 LibPinyinConfig::readDefaultValues (void)
 {
@@ -200,9 +246,20 @@ LibPinyinConfig::readDefaultValues (void)
         m_page_size = 5;
         g_warn_if_reached ();
     }
+
+    gint index = read (CONFIG_DISPLAY_STYLE, 0);
+    m_display_style = DISPLAY_STYLE_TRADITIONAL;
+
+    for (guint i = 0; i < G_N_ELEMENTS (display_style_options); i++) {
+        if (index == display_style_options[i].display_style_index) {
+            /* set display style option. */
+            m_display_style = display_style_options[i].display_style;
+        }
+    }
+
     m_remember_every_input = read (CONFIG_REMEMBER_EVERY_INPUT, false);
 
-    const gint index = read (CONFIG_SORT_OPTION, 0);
+    index = read (CONFIG_SORT_OPTION, 0);
     m_sort_option = SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY;
 
     for (guint i = 0; i < G_N_ELEMENTS (sort_options); i++) {
@@ -224,6 +281,9 @@ LibPinyinConfig::readDefaultValues (void)
     m_both_switch = read (CONFIG_BOTH_SWITCH, "");
     m_trad_switch = read (CONFIG_TRAD_SWITCH, "<Control><Shift>f");
 
+    m_network_dictionary_start_timestamp = read (CONFIG_NETWORK_DICTIONARY_START_TIMESTAMP, (gint64) 0);
+    m_network_dictionary_end_timestamp = read (CONFIG_NETWORK_DICTIONARY_END_TIMESTAMP, (gint64) 0);
+
     /* fuzzy pinyin */
     if (read (CONFIG_FUZZY_PINYIN, false))
         m_option_mask |= PINYIN_AMB_ALL;
@@ -240,6 +300,29 @@ LibPinyinConfig::readDefaultValues (void)
             m_option &= ~options[i].option;
         }
     }
+
+    m_enable_cloud_input = read (CONFIG_INIT_ENABLE_CLOUD_INPUT, false);
+
+    /* set cloud input source option. */
+    index = read (CONFIG_CLOUD_INPUT_SOURCE, 0);
+    m_cloud_input_source = CLOUD_INPUT_SOURCE_BAIDU;
+    for (guint i = 0; i < G_N_ELEMENTS (cloud_input_source_options); i++) {
+        if (index == cloud_input_source_options[i].cloud_input_source_index) {
+            m_cloud_input_source = cloud_input_source_options[i].cloud_input_source;
+        }
+    }
+
+    m_cloud_candidates_number = read (CONFIG_CLOUD_CANDIDATES_NUMBER, 1);
+    if (m_cloud_candidates_number > 10 || m_cloud_candidates_number < 1) {
+        m_cloud_candidates_number = 1;
+        g_warn_if_reached ();
+    }
+
+    m_cloud_request_delay_time = read (CONFIG_CLOUD_REQUEST_DELAY_TIME, 600);
+    if (m_cloud_request_delay_time > 2000 || m_cloud_request_delay_time < 200) {
+        m_cloud_request_delay_time = 600;
+        g_warn_if_reached ();
+    }
 #endif
 }
 
@@ -259,13 +342,22 @@ LibPinyinConfig::valueChanged (const std::string &schema_id,
             m_orientation = IBUS_ORIENTATION_HORIZONTAL;
             g_warn_if_reached ();
         }
-    }
-    else if (CONFIG_PAGE_SIZE == name) {
+    } else if (CONFIG_PAGE_SIZE == name) {
         m_page_size = normalizeGVariant (value, 5);
         if (m_page_size > 10) {
             m_page_size = 5;
             g_warn_if_reached ();
         }
+    } else if (CONFIG_DISPLAY_STYLE == name) {
+        const gint index = normalizeGVariant (value, 0);
+        m_display_style = DISPLAY_STYLE_TRADITIONAL;
+
+        for (guint i = 0; i < G_N_ELEMENTS (display_style_options); i++) {
+            if (index == display_style_options[i].display_style_index) {
+                /* set display style option. */
+                m_display_style = display_style_options[i].display_style;
+            }
+        }
     } else if (CONFIG_REMEMBER_EVERY_INPUT == name) {
         m_remember_every_input = normalizeGVariant (value, false);
     } else if (CONFIG_SORT_OPTION == name) {
@@ -296,6 +388,39 @@ LibPinyinConfig::valueChanged (const std::string &schema_id,
         m_both_switch = normalizeGVariant (value, std::string (""));
     } else if (CONFIG_TRAD_SWITCH == name) {
         m_trad_switch = normalizeGVariant (value, std::string ("<Control><Shift>f"));
+    } else if (CONFIG_NETWORK_DICTIONARY_START_TIMESTAMP == name) {
+        m_network_dictionary_start_timestamp = normalizeGVariant (value, (gint64) 0);
+    } else if (CONFIG_NETWORK_DICTIONARY_END_TIMESTAMP == name) {
+        m_network_dictionary_end_timestamp = normalizeGVariant (value, (gint64) 0);
+    }
+    /*cloud input*/
+    else if (CONFIG_INIT_ENABLE_CLOUD_INPUT == name) {
+        m_enable_cloud_input = normalizeGVariant (value, false);
+    }
+    else if (CONFIG_CLOUD_INPUT_SOURCE == name) {
+        const gint index = normalizeGVariant (value, 0);
+        m_cloud_input_source = CLOUD_INPUT_SOURCE_BAIDU;
+
+        /* set cloud input source option. */
+        for (guint i = 0; i < G_N_ELEMENTS (cloud_input_source_options); i++) {
+            if (index == cloud_input_source_options[i].cloud_input_source_index) {
+                m_cloud_input_source = cloud_input_source_options[i].cloud_input_source;
+            }
+        }
+    }
+    else if (CONFIG_CLOUD_CANDIDATES_NUMBER == name) {
+        m_cloud_candidates_number = normalizeGVariant (value, 1);
+        if (m_cloud_candidates_number > 10 || m_cloud_candidates_number < 1) {
+            m_cloud_candidates_number = 1;
+            g_warn_if_reached ();
+        }
+    }
+    else if (CONFIG_CLOUD_REQUEST_DELAY_TIME == name) {
+        m_cloud_request_delay_time = read (CONFIG_CLOUD_REQUEST_DELAY_TIME, 600);
+        if (m_cloud_request_delay_time > 2000 || m_cloud_request_delay_time < 200) {
+            m_cloud_request_delay_time = 600;
+            g_warn_if_reached ();
+        }
     }
     /* fuzzy pinyin */
     else if (CONFIG_FUZZY_PINYIN == name) {
@@ -483,11 +608,13 @@ PinyinConfig::valueChanged (const std::string &schema_id,
         m_auto_commit = normalizeGVariant (value, false);
     else if (CONFIG_IMPORT_DICTIONARY == name) {
         std::string filename = normalizeGVariant (value, std::string(""));
-        LibPinyinBackEnd::instance ().importPinyinDictionary (filename.c_str ());
+        if (!filename.empty ())
+            LibPinyinBackEnd::instance ().importPinyinDictionary (filename.c_str ());
     }
     else if (CONFIG_EXPORT_DICTIONARY == name) {
         std::string filename = normalizeGVariant (value, std::string(""));
-        LibPinyinBackEnd::instance ().exportPinyinDictionary (filename.c_str ());
+        if (!filename.empty ())
+            LibPinyinBackEnd::instance ().exportPinyinDictionary (filename.c_str ());
     }
     else if (CONFIG_CLEAR_USER_DATA == name) {
         std::string target = normalizeGVariant (value, std::string(""));
